.. :changelog:

History
-------

v0.1.3
++++++

- Switched unpacking to use library generator retrieve_all

v0.1.2
++++++

- Fix for creating a folder for new card templates.

v0.1.1
++++++

- Added guards to ensure directories exist before use.
- Packing now starts the library anew if it already exists.

v0.1.0
++++++

- First PyPi release.
